@@ -1,5 +1,5 @@
 package Net::Stripe::Charge;
-$Net::Stripe::Charge::VERSION = '0.36';
+$Net::Stripe::Charge::VERSION = '0.37';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -25,11 +25,15 @@ has 'application_fee'     => (is => 'ro', isa => 'Maybe[Int]');
 has 'metadata'            => (is => 'rw', isa => 'Maybe[HashRef]');
 has 'invoice'             => (is => 'ro', isa => 'Maybe[Str]');
 has 'receipt_email'       => (is => 'ro', isa => 'Maybe[Str]');
+has 'status'              => (is => 'ro', isa => 'Maybe[Str]');
+has 'capture'             => (is => 'ro', isa => 'Maybe[Bool]');
 
 method form_fields {
+    my $capture = ( !defined( $self->capture ) || $self->capture ) ? 'true' : 'false';
     return (
         $self->fields_for('card'),
         $self->form_fields_for_metadata(),
+        capture => $capture,
         map { $_ => $self->$_ }
             grep { defined $self->$_ }
                 qw/amount currency customer description application_fee receipt_email/
@@ -49,7 +53,7 @@ Net::Stripe::Charge - represent an Charge object from Stripe
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 AUTHORS
 
